=== modified file 'NEWS'
--- NEWS	2006-11-21 01:08:52 +0000
+++ NEWS	2006-11-25 20:38:39 +0000
@@ -23,6 +23,9 @@
     * WSGI-compatible HTTP smart server.  See ``doc/http_smart_server.txt``.
       (Andrew Bennetts)
 
+    * ``bzr merge`` now has an option ``--pull`` to fall back to pull if
+      local is fully merged into remote.
+
   INTERNALS:
 
     * New -D option given before the command line turns on debugging output

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-11-22 16:16:43 +0000
+++ bzrlib/builtins.py	2006-11-25 20:38:39 +0000
@@ -2197,7 +2197,10 @@
                      Option('show-base', help="Show base revision text in "
                             "conflicts"), 
                      Option('uncommitted', help='Apply uncommitted changes'
-                            ' from a working copy, instead of branch changes')]
+                            ' from a working copy, instead of branch changes'),
+                     Option('pull', help='If the branches are not diverged,'
+                            ' chage to remote revision as via pull command'),
+                     ]
 
     def help(self):
         from inspect import getdoc
@@ -2205,7 +2208,7 @@
 
     def run(self, branch=None, revision=None, force=False, merge_type=None,
             show_base=False, reprocess=False, remember=False, 
-            uncommitted=False):
+            uncommitted=False, pull=False):
         if merge_type is None:
             merge_type = _mod_merge.Merge3Merger
 
@@ -2276,6 +2279,7 @@
                     merge_type=merge_type,
                     reprocess=reprocess,
                     show_base=show_base,
+                    pull=pull,
                     pb=pb, file_list=interesting_files)
             finally:
                 pb.finished()
@@ -2932,6 +2936,7 @@
                   this_dir=None, backup_files=False,
                   merge_type=None,
                   file_list=None, show_base=False, reprocess=False,
+                  pull=False,
                   pb=DummyProgress()):
     """Merge changes into a tree.
 
@@ -2986,6 +2991,12 @@
         if merger.base_rev_id == merger.other_rev_id:
             note('Nothing to do.')
             return 0
+        if file_list is None:
+            if pull and merger.base_rev_id == merger.this_rev_id:
+                count = merger.this_tree.pull(merger.this_branch,
+                        False, merger.other_rev_id)
+                note('%d revision(s) pulled.' % (count,))
+                return 0
         merger.backup_files = backup_files
         merger.merge_type = merge_type 
         merger.set_interesting_files(file_list)

=== modified file 'bzrlib/tests/blackbox/test_merge.py'
--- bzrlib/tests/blackbox/test_merge.py	2006-09-19 19:30:15 +0000
+++ bzrlib/tests/blackbox/test_merge.py	2006-11-25 20:38:39 +0000
@@ -239,3 +239,33 @@
         tree_b.revert([])
         self.run_bzr_error(('Cannot use --uncommitted and --revision',), 
                            'merge', '../a', '--uncommitted', '-r1')
+
+    def pullable_branch(self):
+        os.mkdir('a')
+        os.chdir('a')
+        self.example_branch()
+        os.chdir('..')
+        self.runbzr('branch a b')
+        os.chdir('b')
+        file('goodbye', 'wt').write('quux')
+        self.runbzr(['commit', '-m', "mode u's are always good"])
+        os.chdir('../a')
+
+    def pullable_branch(self):
+        tree_a = self.make_branch_and_tree('a')
+        self.build_tree(['a/file'])
+        tree_a.add(['file'])
+        self.id1 = tree_a.commit('commit 1')
+        
+        tree_b = self.make_branch_and_tree('b')
+        tree_b.pull(tree_a.branch)
+        file('b/file', 'wb').write('foo')
+        self.id2 = tree_b.commit('commit 2')
+
+    def test_merge_pull(self):
+        self.pullable_branch()
+        os.chdir('a')
+        (out, err) = self.run_bzr('merge', '--pull', '../b')
+        self.assertContainsRe(err, '1 revision\\(s\\) pulled')
+        tree_a = WorkingTree.open('.')
+        self.assertEqual([self.id2], tree_a.get_parent_ids())

